*******
Authors
*******

Leads
=====

- Jérôme Lafréchoux  `@lafrech <https://github.com/lafrech>`_
- David Fédérique `@davidfrederique <https://github.com/davidfrederique>`_

Contributors (chronological)
============================

- Ryan Yin `@ryan4yin <https://github.com/ryan4yin>`_
- Douglas Thor `@dougthor42 <https://github.com/dougthor42>`_
- Steven Loria `@sloria <https://github.com/sloria>`_
- Jón Bjarnason `@nonnib <https://github.com/nonnib>`_
